import yaml
import os
import sys
from doreah.control import mainfunction
from . import DATA_DIR


DATA_DIR = os.path.join(DATA_DIR,"ytd")
settingsfile = os.path.join(DATA_DIR,"presets.yml")

@mainfunction({},shield=True)
def main(preset=None,url=None,new=None,path=None):
	if new is None and path is None:
		with open(settingsfile,"r") as f:
			settings = yaml.safe_load(f)

		selected = settings[preset]
		os.chdir(selected["path"])
		os.system("youtube-dl " + url)
	elif new is not None and path is not None:
		settings = {}
		assert os.path.exists(path)
		with open(settingsfile,"r") as f:
			settings = yaml.safe_load(f)

		settings[new] = {"path":path}

		with open(settingsfile,"w") as f:
			yaml.dump(settings,f)

	else:
		print("You need to specify --new and --path to create a new preset!")


def create_bash_complete():

	pass



import setuptools
import importlib
import sys
import os
import shutil
import glob
from doreah.control import mainfunction

@mainfunction({},shield=True)
def main(packagename):

	assert os.path.exists(packagename)
	sys.argv = (sys.argv[0],"sdist","bdist_wheel")

	# use local package!
	sys.path = ["."] + sys.path

	module = importlib.import_module(packagename)
	pkginfo = importlib.import_module(".__pkginfo__",package=packagename)
	pkginfo = pkginfo.__dict__


	# extract info

	with open("README.md", "r") as fh:
	    long_description = fh.read()

	setuptools.setup(
	    name=pkginfo.get("links",{}).get("pypi") or pkginfo["name"],
	    version=".".join(str(n) for n in pkginfo["version"]),
	    author=pkginfo["author"]["name"],
	    author_email=pkginfo["author"]["email"],
	    description=pkginfo["desc"],
		license=pkginfo.get("license") or "GPLv3",
	    long_description=long_description,
	    long_description_content_type="text/markdown",
	    url="https://github.com/" + pkginfo["author"]["github"] + "/" + (pkginfo.get("links",{}).get("github") or pkginfo.get("name")),
	    packages=[packagename],
	    classifiers=[
	        "Programming Language :: Python :: 3",
	        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
	        "Operating System :: OS Independent",
	    ],
		python_requires=">=3.5",
		install_requires=pkginfo["requires"],
		package_data={'': pkginfo["resources"]},
		include_package_data=True,
		entry_points = {
			"console_scripts":[
				cmd + " = " + pkginfo["name"] + "." + pkginfo["commands"][cmd]
				for cmd in pkginfo["commands"]
			]
		}
	)


	os.system("git tag v" + ".".join(str(n) for n in pkginfo["version"]))


	os.system("python3 -m twine upload --skip-existing dist/*")

	shutil.rmtree("build")
	shutil.rmtree("dist")
	for d in glob.glob("*.egg-info"):
		shutil.rmtree(d)



import sys
import os
import random
from send2trash import send2trash
from doreah.control import mainfunction


@mainfunction({},shield=True)
def main(*args):
	vids = args[0:-1]
	out = args[-1]

	assert not os.path.exists(out)

	files = []

	rand = random.randrange(100000000,999999999)
	rand = str(rand)

	i = 0
	for v in vids:
		if os.path.isfile(v):
			print(v,"is a file")
			files.append(v)
		else:
			print(v,"is not a file")
			filename = rand + "_" + str(i)
			cmd = "youtube-dl -o \"" + filename + ".%(ext)s\" --merge-output-format mkv " + v
			print("Command",cmd)
			assert 0 == os.system(cmd)
			files.append(filename + ".mkv")

		i += 1


	with open(rand + "_file.txt","w") as fil:
		fil.write("\n".join("file '" + f + "'" for f in files))

	assert 0 == os.system("ffmpeg -f concat -safe 0 -i " + rand + "_file.txt -c copy " + out)
	os.remove(rand + "_file.txt")

	for f in files:
		send2trash(f)



import sys
import os
import re
import tabulate
from doreah.control import mainfunction

@mainfunction({},shield=True)
def main(*args):

	repo = args[0]

	archivelist = os.popen("borg list " + repo).read()

	archives = archivelist.split("\n")[:-1]
	archives = [a.split() for a in archives]
	archivenames = [a[0] for a in archives]

	sizes = []
	for a in archivenames:
		print("Analyzing archive",a)
		info = os.popen("borg info " + repo + "::" + a).read()
		info = info.split("\n")
		info = [line for line in info if line.startswith("This archive:")][0]
		_, origsize, compressedsize, dedupsize = re.split(r'\s{2,}', info)
		sizes.append([a,origsize,compressedsize,dedupsize])

	print(tabulate.tabulate(sizes,headers=["Archive","Original Size","Compressed Size","Deduplicated Size"]))



import os
import shutil
from doreah.control import mainfunction

@mainfunction({},shield=True)
def main():
	STEAMDIR = "~/.steam/steam/steamapps/common/Mass Effect 2"
	APPID = 24980

	tempdir = os.path.join(os.path.expanduser(STEAMDIR),"dlc_installers")
	os.makedirs(tempdir)

	for f in os.listdir("."):
		if f.endswith(".exe"):
			shutil.copy(f,tempdir)

			os.system("protontricks -c 'wine ./dlc_installers/" + f + "' " + str(APPID))



from . import modulenames

name = "yeonji"
author = {
	"name":"Johannes Krattenmacher",
	"email":"python@krateng.dev",
	"github":"krateng"
}
desc = "Collection of command line tools"
version = 0,5,1


requires = [
	"tabulate",
	"send2trash"
]

resources = [
]



commands = {
	mod:mod + ":main"
	for mod in modulenames
}




# local data
import os
try:
	DATA_DIR = os.environ["XDG_DATA_HOME"].split(":")[0]
	assert os.path.exists(DATA_DIR)
except:
	DATA_DIR = os.path.join(os.environ["HOME"],".local/share/")
DATA_DIR = os.path.join(DATA_DIR,"yeonji")
os.makedirs(DATA_DIR,exist_ok=True)

# package finder
import pkgutil, importlib, sys, inspect
modulenames = [modname for importer, modname, ispkg in pkgutil.iter_modules(__import__(__name__).__path__)]
#modules = {name:importlib.import_module("." + name,package=__name__) for name in modulenames}


# give packages their own directories
for m in modulenames:
#	mod = modules[m]
	dir = os.path.join(DATA_DIR,m)
	os.makedirs(dir,exist_ok=True)
	#print("assigning",dir,"to",mod)
	#mod.DATA_DIR = dir
	#sys.modules[__name__ + "." + m] = mod

#def datadir():
#	fr = inspect.stack()[1]
#	mod = inspect.getmodule(fr[0])
#	return os.path.join(DATA_DIR,mod.__name__)



import setuptools
import importlib

module = importlib.import_module(setuptools.find_packages()[0])

with open("README.md", "r") as fh:
	long_description = fh.read()

setuptools.setup(
	name=module.name,
	version=".".join(str(n) for n in module.version),
	author=module.author["name"],
	author_email=module.author["email"],
	description=module.desc,
	license="GPLv3",
	long_description=long_description,
	long_description_content_type="text/markdown",
	url="https://github.com/" + module.author["github"] + "/" + module.name,
	packages=setuptools.find_packages(),
	classifiers=[
		"Programming Language :: Python :: 3",
		"License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
		"Operating System :: OS Independent",
	],
	python_requires=">=3.5",
	install_requires=module.requires,
	package_data={'': module.resources},
	include_package_data=True,
	entry_points = {
		"console_scripts":[
			cmd + " = " + module.name + "." + module.commands[cmd]
			for cmd in module.commands
		]
	}
)



import sys
import os
import re
from doreah.control import mainfunction


@mainfunction({},shield=True)
def main(*args):
	if (len(args) < 2):
		print("You need to specify a number and a title, son!")
		exit()

	try:
		num = int(args[0])
	except:
		print("That doesn't look like a valid number.")
		exit()

	if (" " in args[1]):
		title = args[1]	#if something was given in parantheses, it's probably meant to be the title even if there are more arguemnts
	else:
		title = " ".join(args[1:])

	convert = False

	if (os.path.exists("track" + str(num) + ".cdda.flac")):
		filename = "track" + str(num) + ".cdda.flac"
		numstr = str(num)
	elif (os.path.exists("track0" + str(num) + ".cdda.flac")):
		filename = "track0" + str(num) + ".cdda.flac"
		numstr = "0" + str(num)
	elif (os.path.exists("track00" + str(num) + ".cdda.flac")):
		filename = "track00" + str(num) + ".cdda.flac"
		numstr = "00" + str(num)


	elif (os.path.exists("track" + str(num) + ".cdda.wav")):
		filename = "track" + str(num) + ".cdda.wav"
		numstr = str(num)
		convert = True
	elif (os.path.exists("track0" + str(num) + ".cdda.wav")):
		filename = "track0" + str(num) + ".cdda.wav"
		numstr = "0" + str(num)
		convert = True
	elif (os.path.exists("track00" + str(num) + ".cdda.wav")):
		filename = "track00" + str(num) + ".cdda.wav"
		numstr = "00" + str(num)
		convert = True




	else:
		print("File could not be found. Are you sure you ripped this with cdparanoia?")
		exit()

	unixtitle = title.replace(" - ","-").replace(" ",".")
	unixtitle = ''.join(c for c in unixtitle if (c.isalpha() or c=="_" or c=="-" or c=="."))
	outputfilename = numstr + "." + unixtitle + ".flac"


	if (convert):
		print("Recoding WAV file...")
		os.system("ffmpeg -i " + filename + " " + outputfilename)
	else:
		os.rename(filename,outputfilename)


	print("Tagging flac file...")
	os.system("metaflac --set-tag=TITLE='" + title + "' " + outputfilename)

	print("All done!")
